<?php

namespace Vmc\Sitemap\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Vmc\Sitemap\Interfaces\SitemapRepositoryInterface;
use Vmc\Sitemap\Repositories\Presenter\SitemapItemTransformer;

/**
 * Pubic API controller class.
 */
class SitemapPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Vmc\Sitemap\Interfaces\SitemapRepositoryInterface $sitemap
     *
     * @return type
     */
    public function __construct(SitemapRepositoryInterface $sitemap)
    {
        $this->repository = $sitemap;
        parent::__construct();
    }

    /**
     * Show sitemap's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $sitemaps = $this->repository
            ->setPresenter('\\Vmc\\Sitemap\\Repositories\\Presenter\\SitemapListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $sitemaps['code'] = 2000;
        return response()->json($sitemaps)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show sitemap.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $sitemap = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($sitemap)) {
            $sitemap         = $this->itemPresenter($module, new SitemapItemTransformer);
            $sitemap['code'] = 2001;
            return response()->json($sitemap)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
