<?php

namespace Vmc\Sitemap\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Vmc\Sitemap\Http\Requests\SitemapRequest;
use Vmc\Sitemap\Interfaces\SitemapRepositoryInterface;
use Vmc\Sitemap\Models\Sitemap;

/**
 * User API controller class.
 */
class SitemapUserController extends BaseController
{
    /**
     * Initialize sitemap controller.
     *
     * @param type SitemapRepositoryInterface $sitemap
     *
     * @return type
     */
    public function __construct(SitemapRepositoryInterface $sitemap)
    {
        $this->repository = $sitemap;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Vmc\Sitemap\Repositories\Criteria\SitemapUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of sitemap.
     *
     * @return json
     */
    public function index(SitemapRequest $request)
    {
        $sitemaps  = $this->repository
            ->setPresenter('\\Vmc\\Sitemap\\Repositories\\Presenter\\SitemapListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $sitemaps['code'] = 2000;
        return response()->json($sitemaps) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display sitemap.
     *
     * @param Request $request
     * @param Model   Sitemap
     *
     * @return Json
     */
    public function show(SitemapRequest $request, Sitemap $sitemap)
    {

        if ($sitemap->exists) {
            $sitemap         = $sitemap->presenter();
            $sitemap['code'] = 2001;
            return response()->json($sitemap)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new sitemap.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(SitemapRequest $request, Sitemap $sitemap)
    {
        $sitemap         = $sitemap->presenter();
        $sitemap['code'] = 2002;
        return response()->json($sitemap)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new sitemap.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(SitemapRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $sitemap          = $this->repository->create($attributes);
            $sitemap          = $sitemap->presenter();
            $sitemap['code']  = 2004;

            return response()->json($sitemap)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show sitemap for editing.
     *
     * @param Request $request
     * @param Model   $sitemap
     *
     * @return json
     */
    public function edit(SitemapRequest $request, Sitemap $sitemap)
    {
        if ($sitemap->exists) {
            $sitemap         = $sitemap->presenter();
            $sitemap['code'] = 2003;
            return response()-> json($sitemap)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the sitemap.
     *
     * @param Request $request
     * @param Model   $sitemap
     *
     * @return json
     */
    public function update(SitemapRequest $request, Sitemap $sitemap)
    {
        try {

            $attributes = $request->all();

            $sitemap->update($attributes);
            $sitemap         = $sitemap->presenter();
            $sitemap['code'] = 2005;

            return response()->json($sitemap)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the sitemap.
     *
     * @param Request $request
     * @param Model   $sitemap
     *
     * @return json
     */
    public function destroy(SitemapRequest $request, Sitemap $sitemap)
    {

        try {

            $t = $sitemap->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('sitemap::sitemap.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
