<?php

namespace Vmc\Sitemap\Http\Controllers;
use Litepie\Sitemap\Http\Requests\SitemapRequest;
use Litepie\Sitemap\Models\Sitemap;

trait SitemapWorkflow {
	
    /**
     * Workflow controller function for sitemap.
     *
     * @param Model   $sitemap
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(SitemapRequest $request, Sitemap $sitemap, $step)
    {

        try {

            $sitemap->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('sitemap::sitemap.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/sitemap/sitemap/' . $sitemap->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/sitemap/sitemap/' . $sitemap->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for sitemap.
     *
     * @param Model   $sitemap
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Sitemap $sitemap, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $sitemap->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('sitemap::sitemap.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('sitemap::admin.sitemap.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('sitemap::admin.sitemap.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('sitemap::admin.sitemap.message', $data)->render();

        }

    }
}