<?php

namespace Vmc\Sitemap\Policies;

use App\User;
use Vmc\Sitemap\Models\Sitemap;

class SitemapPolicy
{

    /**
     * Determine if the given user can view the sitemap.
     *
     * @param User $user
     * @param Sitemap $sitemap
     *
     * @return bool
     */
    public function view(User $user, Sitemap $sitemap)
    {
        if ($user->canDo('sitemap.sitemap.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $sitemap->user_id;
    }

    /**
     * Determine if the given user can create a sitemap.
     *
     * @param User $user
     * @param Sitemap $sitemap
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('sitemap.sitemap.create');
    }

    /**
     * Determine if the given user can update the given sitemap.
     *
     * @param User $user
     * @param Sitemap $sitemap
     *
     * @return bool
     */
    public function update(User $user, Sitemap $sitemap)
    {
        if ($user->canDo('sitemap.sitemap.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $sitemap->user_id;
    }

    /**
     * Determine if the given user can delete the given sitemap.
     *
     * @param User $user
     * @param Sitemap $sitemap
     *
     * @return bool
     */
    public function destroy(User $user, Sitemap $sitemap)
    {
        if ($user->canDo('sitemap.sitemap.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $sitemap->user_id;
    }

    /**
     * Determine if the given user can verify the given sitemap.
     *
     * @param User $user
     * @param Sitemap $sitemap
     *
     * @return bool
     */
    public function verify(User $user, Sitemap $sitemap)
    {
        if ($user->canDo('sitemap.sitemap.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('sitemap.sitemap.verify') 
        && $user->is('manager')
        && $sitemap->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sitemap.
     *
     * @param User $user
     * @param Sitemap $sitemap
     *
     * @return bool
     */
    public function approve(User $user, Sitemap $sitemap)
    {
        if ($user->canDo('sitemap.sitemap.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
