<?php

namespace Vmc\Sitemap\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Vmc\Sitemap\Models\Sitemap;

class SitemapAction
{
    /**
     * Perform the complete action.
     *
     * @param Sitemap $sitemap
     *
     * @return Sitemap
     */
    public function complete(Sitemap $sitemap)
    {
        try {
            $sitemap->status = 'complete';
            return $sitemap->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Sitemap $sitemap
     *
     * @return Sitemap
     */public function verify(Sitemap $sitemap)
    {
        try {
            $sitemap->status = 'verify';
            return $sitemap->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Sitemap $sitemap
     *
     * @return Sitemap
     */public function approve(Sitemap $sitemap)
    {
        try {
            $sitemap->status = 'approve';
            return $sitemap->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Sitemap $sitemap
     *
     * @return Sitemap
     */public function publish(Sitemap $sitemap)
    {
        try {
            $sitemap->status = 'publish';
            return $sitemap->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Sitemap $sitemap
     *
     * @return Sitemap
     */
    public function archive(Sitemap $sitemap)
    {
        try {
            $sitemap->status = 'archive';
            return $sitemap->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Sitemap $sitemap
     *
     * @return Sitemap
     */
    public function unpublish(Sitemap $sitemap)
    {
        try {
            $sitemap->status = 'unpublish';
            return $sitemap->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
