<?php

namespace Vmc\Sitemap\Workflow;

use Vmc\Sitemap\Models\Sitemap;
use Validator;

class SitemapValidator
{

    /**
     * Determine if the given sitemap is valid for complete status.
     *
     * @param Sitemap $sitemap
     *
     * @return bool / Validator
     */
    public function complete(Sitemap $sitemap)
    {
        return Validator::make($sitemap->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given sitemap is valid for verify status.
     *
     * @param Sitemap $sitemap
     *
     * @return bool / Validator
     */
    public function verify(Sitemap $sitemap)
    {
        return Validator::make($sitemap->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given sitemap is valid for approve status.
     *
     * @param Sitemap $sitemap
     *
     * @return bool / Validator
     */
    public function approve(Sitemap $sitemap)
    {
        return Validator::make($sitemap->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given sitemap is valid for publish status.
     *
     * @param Sitemap $sitemap
     *
     * @return bool / Validator
     */
    public function publish(Sitemap $sitemap)
    {
        return Validator::make($sitemap->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given sitemap is valid for archive status.
     *
     * @param Sitemap $sitemap
     *
     * @return bool / Validator
     */
    public function archive(Sitemap $sitemap)
    {
        return Validator::make($sitemap->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given sitemap is valid for unpublish status.
     *
     * @param Sitemap $sitemap
     *
     * @return bool / Validator
     */
    public function unpublish(Sitemap $sitemap)
    {
        return Validator::make($sitemap->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
